@@ -1,9 +1,9 @@
 package Module::CheckVersion;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2015-07-31'; # DATE
+our $DATE = '2015-08-19'; # DATE
 our $DIST = 'Module-CheckVersion'; # DIST
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -132,7 +132,7 @@ Module::CheckVersion - Check module (e.g. check latest version) with CPAN (or eq
 
 =head1 VERSION
 
-This document describes version 0.03 of Module::CheckVersion (from Perl distribution Module-CheckVersion), released on 2015-07-31.
+This document describes version 0.04 of Module::CheckVersion (from Perl distribution Module-CheckVersion), released on 2015-08-19.
 
 =head1 SYNOPSIS
 
@@ -155,9 +155,8 @@ The distribution comes with a CLI: L<check-module-version>.
 
 =head2 check_module_version(%args) -> [status, msg, result, meta]
 
-{en_US Check module (e.g. check latest version) with CPAN (or equivalent repo)}.
+Check module (e.g. check latest version) with CPAN (or equivalent repo).
 
-{en_US 
 Designed to be more general and able to provide more information in the future
 in addition to mere checking of latest version, but checking latest version is
 currently the only implemented feature.
@@ -165,7 +164,6 @@ currently the only implemented feature.
 Can handle non-CPAN modules, as long as you put the appropriate C<$AUTHORITY> in
 your modules and create the C<< Module::CheckVersion::E<lt>schemeE<gt> >> to handle your
 authority scheme.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -175,7 +173,6 @@ Arguments ('*' denotes required arguments):
 
 =item * B<default_authority_scheme> => I<str> (default: "cpan")
 
-{en_US 
 If a module does not set C<$AUTHORITY> (which contains string like
 C<< E<lt>schemeE<gt>:E<lt>extraE<gt> >> like C<cpan:PERLANCAR>), the default authority scheme will be
 determined from this setting. The module C<< Module::CheckVersion::E<lt>schemeE<gt> >> module
@@ -183,14 +180,11 @@ is used to implement actual checking.
 
 Can also be set to undef, in which case when module's C<$AUTHORITY> is not
 available, will return 412 status.
-}
 
 =item * B<module>* => I<str>
 
-{en_US 
 This routine will try to load the module, and retrieve its C<$VERSION>. If
 loading fails will assume module's installed version is undef.
-}
 
 =back
 
